package models

import (
	"fmt"
	"github.com/beego/beego/v2/client/orm"
	"strings"
)

// BusinessConf 商户配置表
type BusinessConf struct {
	Id                 int    `orm:"column(id);pk"`
	CompanyName        string `description:"公司名称"`
	CompanyWatermark   string `description:"公司水印"`
	WatermarkChart     int    `description:"是否在研报图表使用水印"`
	CnPptCoverImgs     string `description:"中文PPT封面图（多图）"`
	CnPptBackgroundImg string `description:"中文PPT背景图"`
	CnPptBottomImg     string `description:"中文PPT封底图"`
	Disclaimer         string `description:"免责声明"`
	EnPptCoverImgs     string `description:"英文PPT封面图（多图）"`
	EnPptBackgroundImg string `description:"英文PPT背景图"`
	EnPptBottomImg     string `description:"英文PPT封底图"`
	UseXf              int    `description:"是否使用科大讯飞：0-否；1-是"`
	XfAppid            string `description:"科大讯飞Appid"`
	XfApiKey           string `description:"科大讯飞ApiKey"`
	XfApiSecret        string `description:"科大讯飞ApiSecret"`
	XfVcn              string `description:"科大讯飞Vcn"`
}

func (m *BusinessConf) TableName() string {
	return "business_conf"
}

func (m *BusinessConf) PrimaryId() string {
	return "id"
}

func (m *BusinessConf) Create() (err error) {
	o := orm.NewOrm()
	id, err := o.Insert(m)
	if err != nil {
		return
	}
	m.Id = int(id)
	return
}

func (m *BusinessConf) CreateMulti(items []*BusinessConf) (err error) {
	if len(items) == 0 {
		return
	}
	o := orm.NewOrm()
	_, err = o.InsertMulti(len(items), items)
	return
}

func (m *BusinessConf) Update(cols []string) (err error) {
	o := orm.NewOrm()
	_, err = o.Update(m, cols...)
	return
}

func (m *BusinessConf) Del() (err error) {
	o := orm.NewOrm()
	sql := fmt.Sprintf(`DELETE FROM %s WHERE %s = ? LIMIT 1`, m.TableName(), m.PrimaryId())
	_, err = o.Raw(sql, m.Id).Exec()
	return
}

func (m *BusinessConf) GetItemById(id int) (item *BusinessConf, err error) {
	o := orm.NewOrm()
	sql := fmt.Sprintf(`SELECT * FROM %s WHERE %s = ? LIMIT 1`, m.TableName(), m.PrimaryId())
	err = o.Raw(sql, id).QueryRow(&item)
	return
}

func (m *BusinessConf) GetItemByCondition(condition string, pars []interface{}) (item *BusinessConf, err error) {
	o := orm.NewOrm()
	sql := fmt.Sprintf(`SELECT * FROM %s WHERE 1=1 %s LIMIT 1`, m.TableName(), condition)
	err = o.Raw(sql, pars).QueryRow(&item)
	return
}

func (m *BusinessConf) GetCountByCondition(condition string, pars []interface{}) (count int, err error) {
	o := orm.NewOrm()
	sql := fmt.Sprintf(`SELECT COUNT(1) FROM %s WHERE 1=1 %s`, m.TableName(), condition)
	err = o.Raw(sql, pars).QueryRow(&count)
	return
}

func (m *BusinessConf) GetItemsByCondition(condition string, pars []interface{}, fieldArr []string, orderRule string) (items []*BusinessConf, err error) {
	o := orm.NewOrm()
	fields := strings.Join(fieldArr, ",")
	if len(fieldArr) == 0 {
		fields = `*`
	}
	order := `ORDER BY create_time DESC`
	if orderRule != "" {
		order = ` ORDER BY ` + orderRule
	}
	sql := fmt.Sprintf(`SELECT %s FROM %s WHERE 1=1 %s %s`, fields, m.TableName(), condition, order)
	_, err = o.Raw(sql, pars).QueryRows(&items)
	return
}

func (m *BusinessConf) GetPageItemsByCondition(condition string, pars []interface{}, fieldArr []string, orderRule string, startSize, pageSize int) (items []*BusinessConf, err error) {
	o := orm.NewOrm()
	fields := strings.Join(fieldArr, ",")
	if len(fieldArr) == 0 {
		fields = `*`
	}
	order := `ORDER BY create_time DESC`
	if orderRule != "" {
		order = ` ORDER BY ` + orderRule
	}
	sql := fmt.Sprintf(`SELECT %s FROM %s WHERE 1=1 %s %s LIMIT ?,?`, fields, m.TableName(), condition, order)
	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&items)
	return
}

// BusinessConfSaveReq 保存配置请求体
type BusinessConfSaveReq struct {
	CompanyName        string   `description:"公司名称"`
	CompanyWatermark   string   `description:"公司水印"`
	WatermarkChart     int      `description:"是否在研报图表使用水印"`
	CnPptCoverImgs     []string `description:"中文PPT封面图（多图）"`
	CnPptBackgroundImg string   `description:"中文PPT背景图"`
	CnPptBottomImg     string   `description:"中文PPT封底图"`
	Disclaimer         string   `description:"免责声明"`
	EnPptCoverImgs     []string `description:"英文PPT封面图（多图）"`
	EnPptBackgroundImg string   `description:"英文PPT背景图"`
	EnPptBottomImg     string   `description:"英文PPT封底图"`
	UseXf              int      `description:"是否使用科大讯飞：0-否；1-是"`
	XfAppid            string   `description:"科大讯飞Appid"`
	XfApiKey           string   `description:"科大讯飞ApiKey"`
	XfApiSecret        string   `description:"科大讯飞ApiSecret"`
	XfVcn              string   `description:"科大讯飞Vcn"`
}

// BusinessConfItem 商家配置信息
type BusinessConfItem struct {
	CompanyName        string   `description:"公司名称"`
	CompanyWatermark   string   `description:"公司水印"`
	WatermarkChart     int      `description:"是否在研报图表使用水印"`
	CnPptCoverImgs     []string `description:"中文PPT封面图（多图）"`
	CnPptBackgroundImg string   `description:"中文PPT背景图"`
	CnPptBottomImg     string   `description:"中文PPT封底图"`
	Disclaimer         string   `description:"免责声明"`
	EnPptCoverImgs     []string `description:"英文PPT封面图（多图）"`
	EnPptBackgroundImg string   `description:"英文PPT背景图"`
	EnPptBottomImg     string   `description:"英文PPT封底图"`
	UseXf              int      `description:"是否使用科大讯飞：0-否；1-是"`
	XfAppid            string   `description:"科大讯飞Appid"`
	XfApiKey           string   `description:"科大讯飞ApiKey"`
	XfApiSecret        string   `description:"科大讯飞ApiSecret"`
	XfVcn              string   `description:"科大讯飞Vcn"`
}

// GetBusinessConf 获取商家配置
func GetBusinessConf() (item *BusinessConf, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM business_conf LIMIT 1`
	err = o.Raw(sql).QueryRow(&item)
	return
}
